"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initialiseEndpoints = exports.validateWrapperData = void 0;
var listenerHandler_1 = require("./listenerHandler");
var limiterHander_1 = require("./limiterHander");
var validateWrapperData = function (data) {
    if (!data.limiter) {
        data.endpoints.forEach(function (x) {
            if (x.limiter) {
                /* Error thrown if limiter requested when mongo client was not provided */
                throw new Error('Cannot initialise listener without a provided mongoClient');
            }
        });
    }
};
exports.validateWrapperData = validateWrapperData;
var initialiseEndpoints = function (data) {
    var endpoints = data.endpoints, limiter = data.limiter, expressApp = data.expressApp, validateRequest = data.validateRequest, getLimiterIdentifier = data.getLimiterIdentifier;
    var limiterStore = {};
    var enabledList = [];
    endpoints.forEach(function (endpoint) {
        var _a;
        var rateLimiterID = ((_a = endpoint.limiter) === null || _a === void 0 ? void 0 : _a.keyPrefix) || endpoint.name + "rx";
        var endpointLimiter;
        if (limiter) {
            endpointLimiter = limiterHander_1.initaliseRateLimiter({
                limiterStore: limiterStore,
                limiter: limiter,
                limiterOptions: endpoint.limiter,
                rateLimiterID: rateLimiterID,
            });
            if (endpointLimiter)
                limiterStore[rateLimiterID] = endpointLimiter;
        }
        var enabled = listenerHandler_1.runListener({
            expressApp: expressApp,
            endpoint: endpoint,
            endpointLimiter: endpointLimiter,
            validateRequest: validateRequest,
            getLimiterIdentifier: getLimiterIdentifier,
        });
        if (enabled)
            enabledList.push(endpoint.name);
    });
    return { limiterStore: limiterStore, enabledList: enabledList };
};
exports.initialiseEndpoints = initialiseEndpoints;
