"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runListener = void 0;
var messages_1 = require("./messages");
var validationHandler_1 = require("./validationHandler");
var handleRequest = function (_a) {
    var req = _a.req, res = _a.res, endpoint = _a.endpoint, endpointLimiter = _a.endpointLimiter, validateRequest = _a.validateRequest, getLimiterIdentifier = _a.getLimiterIdentifier;
    validationHandler_1.performValidation({
        req: req,
        endpoint: endpoint,
        endpointLimiter: endpointLimiter,
        validateRequest: validateRequest,
        getLimiterIdentifier: getLimiterIdentifier,
    }).then(function (validationResult) {
        if (validationResult.success) {
            endpoint.execute(req, res, __assign(__assign({}, req.headers), validationResult.headers));
        }
        else {
            res
                .status(validationResult.status || 500)
                .send({ text: validationResult.error || messages_1.errorMessages.DEFAULT_ERROR });
        }
    });
};
var runListener = function (_a) {
    var expressApp = _a.expressApp, endpoint = _a.endpoint, endpointLimiter = _a.endpointLimiter, validateRequest = _a.validateRequest, getLimiterIdentifier = _a.getLimiterIdentifier;
    if (endpoint.disabled)
        return false;
    var getRequestOpts = function (req, res) {
        return {
            req: req,
            res: res,
            endpoint: endpoint,
            endpointLimiter: endpointLimiter,
            validateRequest: validateRequest,
            getLimiterIdentifier: getLimiterIdentifier,
        };
    };
    var listenerPath = endpoint.defaultPath
        ? "/" + endpoint.defaultPath + "/" + endpoint.path
        : "/" + endpoint.path;
    switch (endpoint.type.toUpperCase()) {
        case 'GET':
            expressApp.get("" + listenerPath, function (req, res) {
                return handleRequest(getRequestOpts(req, res));
            });
            break;
        case 'POST':
            expressApp.post("" + listenerPath, function (req, res) {
                return handleRequest(getRequestOpts(req, res));
            });
            break;
        case 'PUT':
            expressApp.get("" + listenerPath, function (req, res) {
                return handleRequest(getRequestOpts(req, res));
            });
            break;
        case 'DELETE':
            expressApp.delete("" + listenerPath, function (req, res) {
                return handleRequest(getRequestOpts(req, res));
            });
            break;
        default:
            throw new Error("Invalid listener type found for " + endpoint.name + ", '" + endpoint.type + "' is not valid");
    }
    return true;
};
exports.runListener = runListener;
